/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.groupware.infostore.search;

import java.util.Collection;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.infostore.DocumentMetadata;
import com.openexchange.groupware.infostore.utils.Metadata;


/**
 * {@link SequenceNumberTerm}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class SequenceNumberTerm extends AbstractNumberSearchTerm {

    /**
     * Initializes a new {@link SequenceNumberTerm}.
     *
     * @param sequenceNumberPattern The sequence number pattern
     */
    public SequenceNumberTerm(final ComparablePattern<Number> sequenceNumberPattern) {
        super(sequenceNumberPattern);
    }

    @Override
    public void visit(final SearchTermVisitor visitor) throws OXException {
        if (null != visitor) {
            visitor.visit(this);
        }
    }

    @Override
    public void addField(final Collection<Metadata> col) {
        if (null != col) {
            col.add(Metadata.SEQUENCE_NUMBER_LITERAL);
        }
    }

    @Override
    protected Long getNumber(final DocumentMetadata file) {
        return Long.valueOf(file.getSequenceNumber());
    }

    @Override
    protected boolean compareLongValues() {
        return true;
    }

}
